#region usings
using System;
using System.ComponentModel.Composition;
using System.IO;

using VVVV.PluginInterfaces.V1;
using VVVV.PluginInterfaces.V2;
using VVVV.Utils.VColor;
using VVVV.Utils.VMath;

using VVVV.Core.Logging;
#endregion usings

namespace VVVV.Nodes
{
	#region PluginInfo
	[PluginInfo(Name = "ParentDirectory", Category = "String", Help = "Get parent directories of different levels", Tags = "", Author = "readme")]
	#endregion PluginInfo
	public class StringParentDirectoryNode : IPluginEvaluate
	{
		#region fields & pins
		[Input("Input", StringType = StringType.Directory)]
		public IDiffSpread<string> FInput;
		
		[Input("Parent Level", MinValue = 0)]
		public IDiffSpread<int> FLevels;
		
		[Output("Output", StringType = StringType.Directory)]
		public ISpread<string> FOutput;
		#endregion fields & pins
		
		//called when data for any output pin is requested
		public void Evaluate(int SpreadMax)
		{
			if (FInput.IsChanged || FLevels.IsChanged)
			{
				FOutput.SliceCount = SpreadMax;
				
				for (int i = 0; i < SpreadMax; i++)
				{
					//remove trailing slashes
					string currentLevel = FInput[i].TrimEnd(Path.DirectorySeparatorChar, Path.AltDirectorySeparatorChar);
					
					//iterate over levels, break if reached topmost folder
					for (int j = 0; j < Math.Max(FLevels[i], 0); j++)
					{
						DirectoryInfo parent = Directory.GetParent(currentLevel);
						if (parent != null)
						{
							currentLevel = parent.FullName;
						} else {
							break;
						}
						
					}
					
					FOutput[i] = currentLevel;
					
				}
			}
		}
	}
}
